import { CompilerOptions } from 'typescript';
export declare const TYPE: {
    SPA: "spa";
    NODE: "node";
    BROWSER: "browser";
};
/**
 * Our i18n settings. Only needed for translated projects.
 */
export interface I18nConfig {
    /**
     * The locales your project supports. A locale consists of a language code (expressed
     * by two lower case characters), a `_` and a country code (expressed by two upper case
     * characters). E.g. valid locales are `'en_GB'`, `'de_AT'`, `'it_IT'` and so on.
     *
     * Note that you can save shared translations of a language in a `.properties` file without
     * a country code (e.g. if `'de_DE'` and `'de_AT'` share translations, they can be stored
     * in a `de.properties` file). That way you don't have to save duplicates.
     */
    locales: string[];
    /**
     * The directory where your `.properties` with translations are located. Defaults to `i18n`.
     */
    dir: string;
    /**
     * The directory where your generated translation are placed. Defaults to `dist-i18n`.
     */
    distDir: string;
    /**
     * You can group translations in so called _features_ (e.g. `common`, `errors`, `forms`).
     *
     * Note that the translation keys must be unique, because every feature is merged into
     * _one_ translation file at the end. We do that on purpose, so we can reuse a translated
     * feature like `common-errors` across several projects, but override certain keys with a
     * translated feature like `specific-errors`, if we need to.
     *
     * Features are _optional_.
     */
    features?: string[];
    /**
     * If you translations aren't maintained in your repository, you can optionally provide
     * a _templated URL_ and we try to download the translations. You can set `{locale}` and
     * `{feature}` in your URL as params (e.g. `https://foo.com/i18n?language={locale}&project={feature}`).
     */
    importUrl?: string;
}
/**
 * This is the `ws` configuration used in the projects `package.json`.
 */
export interface WsConfig {
    /**
     * We currently support four types of projects: `'spa'`, `'node'` and `'browser'`.
     */
    type: 'spa' | 'node' | 'browser';
    /**
     * The file extension of your entry file. Either `js`, `ts` or `tsx`.
     * This value is set automatically.
     */
    entryExtension: 'js' | 'ts' | 'tsx';
    /**
     * If this is a TypeScript project, we will save the `tsconfig.json` here.
     */
    tsconfig?: CompilerOptions;
    /**
     * If this is a TypeScript project, we will save the path to `tsconfig.json` here.
     */
    tsconfigPath?: string;
    /**
     * Probably only needed for 'browser' projects currently.
     * See https://webpack.github.io/docs/configuration.html#externals.
     */
    externals?: any;
    /**
     * The directory where your source code is located. Defaults to `'src'`.
     */
    srcDir: string;
    /**
     * The entry file for your source code. This value is set automatically.
     * It could look this: `./src/index.ts`.
     */
    srcEntry: string;
    /**
     * The _optional_ entry file for source code at the root level of a localized spa.
     * This value is set automatically.
     * It could look this: `./src/index.i18n.ts`.
     */
    srcI18nEntry: string;
    /**
     * The directory where your tests are located. Defaults to `'tests'`.
     */
    testsDir: string;
    /**
     * The pattern that is used to find tests
     */
    testsPattern?: string | string[];
    /**
     * The entry file for your unit tests. This value is set automatically.
     * It could look this: `./tests/unit.ts`.
     */
    unitEntry: string;
    /**
     * The entry file for your e2e tests. This value is set automatically.
     * It could look this: `./tests/e2e.ts`.
     */
    e2eEntry: string;
    /**
     * The directory where your development build is generated. Defaults to `'dist'`.
     */
    distDir: string;
    /**
     * The directory where your tests build is generated. Defaults to `'dist-tests'`.
     */
    distTestsDir: string;
    /**
     * The directory where your production build is generated (only SPAs). Defaults to `'dist-release'`.
     */
    distReleaseDir: string;
    /**
     * SPA only.
     * Public path of your app. Defaults to `""`
     * See https://webpack.js.org/configuration/output/#output-publicpath for an explanation.
     */
    publicPath: string;
    /**
     * `targets` taken from [`babel-preset-env`](https://github.com/babel/babel-preset-env).
     * We only use `browsers` and `node` properties for now.
     */
    targets: {
        /**
         * A [browserslist](https://github.com/ai/browserslist) compatible string to specify which
         * browsers should be used for selenium testing (if it is enabled) and for
         * [autoprefixer](https://github.com/postcss/autoprefixer).
         * Defaults to `'> 1%, last 2 versions, Firefox ESR'`.
         */
        browsers: string;
        /**
         * If you want to compile against the current node version, you can specify "node": "current", which would be the same as "node": parseFloat(process.versions.node).
         */
        node: string | number;
    };
    /**
     * Our i18n settings. Only needed for translated projects.
     */
    i18n?: I18nConfig;
    /**
     * Set this to `true` to ignore update notifications.
     */
    ignoreUpdates?: boolean;
}
export interface PackageConfig {
    /**
     * The name of your project taken from `package.json`.
     */
    name: string;
    /**
     * The dependencies of your project.
     */
    dependencies?: {
        [dependency: string]: string;
    };
    /**
     * The devDependencies of your project.
     */
    devDependencies?: {
        [dependency: string]: string;
    };
    /**
     * Flags if this package is private.
     */
    private?: boolean;
    /**
     * A description of your project.
     */
    description?: string;
    /**
     * Keywords which describe your project.
     */
    keywords?: string[];
    /**
     * Path to the generated typescript declarations.
     */
    typings?: string;
    /**
     * This is the `ws` configuration used in the projects `package.json`.
     */
    ws: WsConfig;
}
export declare function validate(pkg: any): PackageConfig;
export declare const project: PackageConfig;
export declare const sourceFilePatterns: string;
